tsseg.algorithms.dynp package
=============================

Exact optimal partitioning for a fixed number of change points.

| **Type:** change point detection
| **Supervision:** semi-supervised only
| **Scope:** globally optimal, multiple cost models
| **Complexity:** O(C Q n²)

**Implementation:** Vendored from ruptures v1.1.8. BSD 2-Clause.

**Reference:** Auger & Lawrence (1989), Bull. Math. Biology.

.. automodule:: tsseg.algorithms.dynp.detector
   :members:
   :show-inheritance:
   :undoc-members:
